==> dokuwiki_0.0.20120125b.orig.tar.gz: dokuwiki-2012-01-25b/inc/lang/ms/lang.php <==
<?php
/**
 * ms language file
 *
 * This file was initially built by fetching translations from other
 * Wiki projects. See the @url lines below. Additional translations
 * and fixes where done for DokuWiki by the people mentioned in the
 * lines starting with @author
 *
 * @url http://svn.wikimedia.org/viewvc/mediawiki/trunk/phase3/languages/messages/MessagesMs.php?view=co
 * @author Markos
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Sunting halaman ini';
$lang['btn_source']            = 'Lihat sumber';
$lang['btn_show']              = 'Baca';
$lang['btn_create']            = 'Cipta halaman';
$lang['btn_search']            = 'Cari';
$lang['btn_save']              = 'Simpan';
$lang['btn_preview']           = 'Pratonton';
$lang['btn_top']               = 'Balik ke mula';
$lang['btn_newer']             = '<< lebih kini';
$lang['btn_older']             = 'lebih awal >>';
$lang['btn_revs']              = 'Sejarah';
$lang['btn_recent']            = 'Perubahan Terkini';
$lang['btn_upload']            = 'Unggah (upload)';
$lang['btn_cancel']            = 'Batal';
$lang['btn_secedit']           = 'Sunting';
$lang['btn_login']             = 'Masuk';
$lang['btn_logout']            = 'Keluar';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Kemaskini';
$lang['btn_delete']            = 'Hapus';
$lang['btn_back']              = 'Balik';
$lang['btn_backlink']          = 'Pautan ke halaman ini';
$lang['btn_backtomedia']       = 'Balik ke rangkaian pilihan fail media';
$lang['btn_subscribe']         = 'Pantau';
$lang['btn_profile']           = 'Kemaskinikan profil';
$lang['btn_reset']             = 'Batalkan suntingan';
$lang['btn_resendpwd']         = 'Emel kata laluan baru';
$lang['btn_draft']             = 'Sunting draf';
$lang['btn_recover']           = 'Pulihkan draf';
$lang['btn_draftdel']          = 'Hapuskan draf';
$lang['btn_revert']            = 'Pulihkan';
$lang['btn_register']          = 'Daftaran';
$lang['btn_apply']             = 'Simpan';
$lang['btn_media']             = 'Manager media';
$lang['loggedinas']            = 'Log masuk sebagai';
$lang['user']                  = 'Nama pengguna';
$lang['pass']                  = 'Kata laluan';
$lang['newpass']               = 'Kata laluan baru';
$lang['oldpass']               = 'Kata laluan lama';
$lang['passchk']               = 'sekali lagi';
$lang['remember']              = 'Sentiasa ingati kata laluan saya.';
$lang['fullname']              = 'Nama sebenar';
$lang['email']                 = 'E-mel';
$lang['profile']               = 'Profil pengguna';
$lang['badlogin']              = 'Maaf, ralat log masuk. Nama pengguna atau kata laluan salah.';
$lang['minoredit']             = 'Suntingan Kecil';
$lang['draftdate']             = 'Draf automatik disimpan pada';
$lang['nosecedit']             = 'Halaman ini telah bertukar pada waktu sementara dan info bahagian ini telah luput. Seluruh halaman telah disarat.';
$lang['regmissing']            = 'Maaf, semua medan mesti diisi';
$lang['reguexists']            = 'Maaf, nama pengguna yang dimasukkan telah diguna. Sila pilih nama yang lain.';
$lang['regsuccess']            = 'Akaun pengguna telah dicipta dan kata laluan telah dikirim kepada e-mel anda.';
$lang['regsuccess2']           = 'Akaun pegguna telah dicipta.';
$lang['regbadmail']            = 'Format alamat e-mel tidak sah. Sila masukkan semula ataupun kosongkan sahaja medan tersebut.';
$lang['regbadpass']            = 'Kedua-dua kata laluan tidak sama. Sila masukkan semula.';
$lang['regpwmail']             = 'Kata laluan Dokuwiki anda';
$lang['reghere']               = 'Belum mendaftar akaun? Dapat akaun baru';
$lang['profna']                = 'Wiki ini tidak menyokong modifikasi profil';
$lang['profnoempty']           = 'Medan nama pengguna atau e-mel yang kosong tidak dibenarkan.';
$lang['profchanged']           = 'Profil pengguna telah dikemaskini.';
$lang['pwdforget']             = 'Terlupa kata laluan? Dapatkan yang baru';
$lang['resendpwd']             = 'Kirimkan kata laluan baru untuk';
$lang['resendpwdmissing']      = 'Maaf, semua medan perlu diisi.';
$lang['resendpwdnouser']       = 'Maaf, nama pengguna ini tidak dapat dicari dalam database kami.';
$lang['resendpwdbadauth']      = 'Maaf, kod authorasi ini tidak sah. Semak bahawa anda telah menggunakan seluruh pautan pengesahan yang dikirim.';
$lang['resendpwdconfirm']      = 'Pautan pengesahan telah dikirimkan ke e-mel anda.';
$lang['resendpwdsuccess']      = 'Kata laluan baru telah dikirimkan ke e-mel anda.';
$lang['license']               = 'Selain daripada yang dinyata, isi wiki ini disediakan dengan lesen berikut:';
$lang['licenseok']             = 'Perhatian: Dengan menyunting halaman ini, anda setuju untuk isi-isi anda dilesen menggunakan lesen berikut:';
$lang['searchmedia']           = 'Cari nama fail:';
$lang['searchmedia_in']        = 'Cari di %s';
$lang['txt_upload']            = 'Pilih fail untuk diunggah';
$lang['txt_filename']          = 'Unggah fail dengan nama (tidak wajib)';
$lang['txt_overwrt']           = 'Timpa fail sekarang';
$lang['lockedby']              = 'Halaman ini telah di';
$lang['fileupload']            = 'Muat naik fail';
$lang['uploadsucc']            = 'Pemuatan naik berjaya';
$lang['uploadfail']            = 'Ralat muat naik';
$lang['uploadxss']             = 'Fail ini mengandungi kod HTML atau kod skrip yang mungkin boleh disalah tafsir oleh pelayar web.';
$lang['toc']                   = 'Jadual Kandungan';
$lang['current']               = 'kini';
$lang['restored']              = 'Telah dikembalikan ke semakan sebelumnya';
$lang['summary']               = 'Paparan';

==> dokuwiki_0.0.20131208.orig.tar.gz: dokuwiki-2013-12-08/inc/lang/ms/lang.php <==
<?php
/**
 * ms language file
 *
 * This file was initially built by fetching translations from other
 * Wiki projects. See the @url lines below. Additional translations
 * and fixes where done for DokuWiki by the people mentioned in the
 * lines starting with @author
 *
 * @url http://svn.wikimedia.org/viewvc/mediawiki/trunk/phase3/languages/messages/MessagesMs.php?view=co
 * @author Markos
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Sunting halaman ini';
$lang['btn_source']            = 'Lihat sumber';
$lang['btn_show']              = 'Baca';
$lang['btn_create']            = 'Cipta halaman';
$lang['btn_search']            = 'Cari';
$lang['btn_save']              = 'Simpan';
$lang['btn_preview']           = 'Pratonton';
$lang['btn_top']               = 'Balik ke mula';
$lang['btn_newer']             = '<< lebih kini';
$lang['btn_older']             = 'lebih awal >>';
$lang['btn_revs']              = 'Sejarah';
$lang['btn_recent']            = 'Perubahan Terkini';
$lang['btn_upload']            = 'Unggah (upload)';
$lang['btn_cancel']            = 'Batal';
$lang['btn_secedit']           = 'Sunting';
$lang['btn_login']             = 'Masuk';
$lang['btn_logout']            = 'Keluar';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Kemaskini';
$lang['btn_delete']            = 'Hapus';
$lang['btn_back']              = 'Balik';
$lang['btn_backlink']          = 'Pautan ke halaman ini';
$lang['btn_backtomedia']       = 'Balik ke rangkaian pilihan fail media';
$lang['btn_subscribe']         = 'Pantau';
$lang['btn_profile']           = 'Kemaskinikan profil';
$lang['btn_reset']             = 'Batalkan suntingan';
$lang['btn_resendpwd']         = 'Emel kata laluan baru';
$lang['btn_draft']             = 'Sunting draf';
$lang['btn_recover']           = 'Pulihkan draf';
$lang['btn_draftdel']          = 'Hapuskan draf';
$lang['btn_revert']            = 'Pulihkan';
$lang['btn_register']          = 'Daftaran';
$lang['btn_apply']             = 'Simpan';
$lang['btn_media']             = 'Manager media';
$lang['loggedinas']            = 'Log masuk sebagai';
$lang['user']                  = 'Nama pengguna';
$lang['pass']                  = 'Kata laluan';
$lang['newpass']               = 'Kata laluan baru';
$lang['oldpass']               = 'Kata laluan lama';
$lang['passchk']               = 'sekali lagi';
$lang['remember']              = 'Sentiasa ingati kata laluan saya.';
$lang['fullname']              = 'Nama sebenar';
$lang['email']                 = 'E-mel';
$lang['profile']               = 'Profil pengguna';
$lang['badlogin']              = 'Maaf, ralat log masuk. Nama pengguna atau kata laluan salah.';
$lang['minoredit']             = 'Suntingan Kecil';
$lang['draftdate']             = 'Draf automatik disimpan pada';
$lang['nosecedit']             = 'Halaman ini telah bertukar pada waktu sementara dan info bahagian ini telah luput. Seluruh halaman telah disarat.';
$lang['regmissing']            = 'Maaf, semua medan mesti diisi';
$lang['reguexists']            = 'Maaf, nama pengguna yang dimasukkan telah diguna. Sila pilih nama yang lain.';
$lang['regsuccess']            = 'Akaun pengguna telah dicipta dan kata laluan telah dikirim kepada e-mel anda.';
$lang['regsuccess2']           = 'Akaun pegguna telah dicipta.';
$lang['regbadmail']            = 'Format alamat e-mel tidak sah. Sila masukkan semula ataupun kosongkan sahaja medan tersebut.';
$lang['regbadpass']            = 'Kedua-dua kata laluan tidak sama. Sila masukkan semula.';
$lang['regpwmail']             = 'Kata laluan Dokuwiki anda';
$lang['reghere']               = 'Belum mendaftar akaun? Dapat akaun baru';
$lang['profna']                = 'Wiki ini tidak menyokong modifikasi profil';
$lang['profnoempty']           = 'Medan nama pengguna atau e-mel yang kosong tidak dibenarkan.';
$lang['profchanged']           = 'Profil pengguna telah dikemaskini.';
$lang['pwdforget']             = 'Terlupa kata laluan? Dapatkan yang baru';
$lang['resendpwd']             = 'Kirimkan kata laluan baru untuk';
$lang['resendpwdmissing']      = 'Maaf, semua medan perlu diisi.';
$lang['resendpwdnouser']       = 'Maaf, nama pengguna ini tidak dapat dicari dalam database kami.';
$lang['resendpwdbadauth']      = 'Maaf, kod authorasi ini tidak sah. Semak bahawa anda telah menggunakan seluruh pautan pengesahan yang dikirim.';
$lang['resendpwdconfirm']      = 'Pautan pengesahan telah dikirimkan ke e-mel anda.';
$lang['resendpwdsuccess']      = 'Kata laluan baru telah dikirimkan ke e-mel anda.';
$lang['license']               = 'Selain daripada yang dinyata, isi wiki ini disediakan dengan lesen berikut:';
$lang['licenseok']             = 'Perhatian: Dengan menyunting halaman ini, anda setuju untuk isi-isi anda dilesen menggunakan lesen berikut:';
$lang['searchmedia']           = 'Cari nama fail:';
$lang['searchmedia_in']        = 'Cari di %s';
$lang['txt_upload']            = 'Pilih fail untuk diunggah';
$lang['txt_filename']          = 'Unggah fail dengan nama (tidak wajib)';
$lang['txt_overwrt']           = 'Timpa fail sekarang';
$lang['lockedby']              = 'Halaman ini telah di';
$lang['fileupload']            = 'Muat naik fail';
$lang['uploadsucc']            = 'Pemuatan naik berjaya';
$lang['uploadfail']            = 'Ralat muat naik';
$lang['uploadxss']             = 'Fail ini mengandungi kod HTML atau kod skrip yang mungkin boleh disalah tafsir oleh pelayar web.';
$lang['toc']                   = 'Jadual Kandungan';
$lang['current']               = 'kini';
$lang['restored']              = 'Telah dikembalikan ke semakan sebelumnya (%s)';
$lang['summary']               = 'Paparan';
